import { css, cx } from "@linaria/core";
import { Image } from "@queenjs/ui";
import { defineComponent } from "vue";
import { bool, func, object } from "vue-types";

export default defineComponent({
  props: {
    active: bool().def(true),
    mat: object<PackageMaterial>(),
    onClick: func(),
  },

  setup(props, { slots }) {
    return () => {
      const { active, mat, onClick } = props;
      return (
        <div
          title={mat?.name || "未命名面料"}
          class={cx(MatCardStyle, active && "active")}
          onClick={onClick}
        >
          <Image class="mat_card" src={mat?.thumbnail?.url} size={100} />
          {slots.default && slots.default()}
        </div>
      );
    };
  },
});

const MatCardStyle = css`
  position: relative;
  display: inline-block;
  border: 1px solid transparent;
  border-radius: 2px;
  line-height: 1;
  cursor: pointer;
  overflow: hidden;
  user-select: none;

  .mat_card {
    width: 100%;
    border-radius: 2px;
  }

  .inf-image {
    height: 100%;
    object-fit: cover;
  }

  &.active {
    border: 1px solid #5a7bef;
    padding: 1px;
  }
`;
